@@ -21,12 +21,12 @@ This is mygpoclient, the gpodder.net API Client Library for Python.
 """
 
 __author__ = 'Thomas Perl <thp@gpodder.org>'
-__version__ = '1.7'
-__website__ = 'http://thp.io/2010/mygpoclient/'
+__version__ = '1.10'
+__website__ = 'http://gpodder.org/mygpoclient/'
 __license__ = 'GNU General Public License v3 or later'
 
-# Default settings for the API client (server hostname and API version)
-HOST = 'gpodder.net'
+# Default settings for the API client (server root url and API version)
+ROOT_URL = 'http://gpodder.net'
 VERSION = 2
 TOPLIST_DEFAULT = 50
 
@@ -34,6 +34,8 @@ TOPLIST_DEFAULT = 50
 user_agent = 'mygpoclient/%s (+%s)' % (__version__, __website__)
 
 # Version checking
+
+
 def require_version(minimum_required):
     """Require a minimum version of the library
 
@@ -53,4 +55,3 @@ def require_version(minimum_required):
     this_version = [int(x) for x in __version__.split('.')]
     minimum_required = [int(x) for x in minimum_required.split('.')]
     return minimum_required <= this_version
-
